"use client";
import { Button } from "@/components/ui/button";
import {
	Card,
	CardContent,
	CardFooter,
	CardHeader,
	CardTitle
} from "@/components/ui/card";
import { Label } from "@/components/ui/label";
import { RadioGroup, RadioGroupItem } from "@/components/ui/radio-group";
import { Separator } from "@/components/ui/separator";
import { Loader2 } from "lucide-react";
import { useTranslations } from "next-intl";
import Image from "next/image";
import { useRouter } from "next/navigation";
import { useEffect, useMemo, useState, useTransition } from "react";
import { toast } from "sonner";

// Import the dialog components
import AddressDialog from "./address-dialog";
import RecipientDialog from "./recipient-dialog";

// Import useUserInfo hook
import { checkout } from "@/servers/actions/checkout-action";
import { updateUserInfo } from "@/servers/actions/userinfo-action";
import { useCart } from "@/servers/data/use-cart";
import { useUserInfo } from "@/servers/data/use-userinfo";



export default function InvoicePageWithTwoDialogs() {
	// Get user info from the hook
	const { userInfo } = useUserInfo();
	const { cart } = useCart();
	const router = useRouter();
	const t = useTranslations("Cart");

	// State for the first dialog (Recipient Info)
	const [recipientInfo, setRecipientInfo] = useState({
		first_name: "",
		middle_name: "",
		last_name: "",
		phone: "",
		email: "",
	});

	// State for the second dialog (Add Address)
	const [fullAddress, setFullAddress] = useState({
		city_id: "",
		city_name: "",
		area_id: "",
		area_name: "",
		address: "",
		additional_description: "",
		delivery_price: 0,
		location_lat: null,
		location_lng: null,
	});

	// State for the selected option
	const [selectedOption, setSelectedOption] = useState("account");
	const [isPending, startTransition] = useTransition();
	const [is_submitted, setIsSubmitted] = useState(false);
	// Add state to control RecipientDialog visibility
	const [isRecipientDialogOpen, setIsRecipientDialogOpen] = useState(false);


	// Handle recipient form submission
	const handleRecipientSave = (data: any) => {
		setRecipientInfo(data);

		// If account option is selected, update the user info in the database
		if (selectedOption === "account") {
			// Check if the data is different from the existing userInfo
			const hasChanges =
				data.first_name !== userInfo?.first_name ||
				data.middle_name !== userInfo?.middle_name ||
				data.last_name !== userInfo?.last_name ||
				data.email !== userInfo?.email;

			// Only update if there are actual changes
			if (hasChanges) {
				startTransition(async () => {
					try {
						const formData = new FormData();
						formData.append("first_name", data.first_name);
						formData.append("middle_name", data.middle_name || "");
						formData.append("last_name", data.last_name);
						formData.append("email", data.email || "");

						const result = await updateUserInfo(formData);
						if (result?.success) {
							toast.success(t("تم تحديث معلومات حسابك بنجاح"), {
								style: { backgroundColor: "green", color: "white" },
							});
						} else {
							if (Array.isArray(result?.message)) {
								result?.message?.map((error: any) => {
									toast.error(t(error.replace(".", "")));
								});
							} else {
								toast.error(t(result?.message));
							}
						}
					} catch (error) {
						console.error("Error updating user info:", error);
						toast.error(t("حدث خطأ أثناء تحديث معلومات حسابك"));
					}
				});
			}
		}
	};

	// Handle address form submission
	const handleAddressSave = (data: any) => {
		setFullAddress(data);

	};

	// Effect to update form data when user info changes or when "استخدام معلومات حسابي" is selected
	useEffect(() => {
		if (selectedOption === "account" && userInfo) {
			setRecipientInfo(userInfo);

		}
	}, [userInfo, selectedOption]);

	// Function to reset form when "ادخال معلومات جديدة" is selected
	const handleOptionChange = (value: string) => {
		// First update the selected option
		setSelectedOption(value);
		setIsSubmitted(false);

		// Then update the recipient info based on the selection
		if (value === "new-info") {
			// Only reset form fields if switching from "account" to "new-info"
			// This preserves the values if already on "new-info" and just reopening
			if (selectedOption !== "new-info") {
				setRecipientInfo({
					first_name: "",
					middle_name: "",
					last_name: "",
					phone: "",
					email: ""
				});
			}
		} else if (value === "account" && userInfo) {
			// Fill form with user info when "استخدام معلومات حسابي" is selected
			setRecipientInfo(userInfo);
		}

		// Force the dialog to open by setting a timeout
		// This ensures the state update happens after the current render cycle
		setTimeout(() => {
			setIsRecipientDialogOpen(true);
		}, 100);
	};

	// Function to handle dialog close
	const handleDialogClose = (open: boolean) => {
		setIsRecipientDialogOpen(open);
	};

	const sum = useMemo(() => {
		return parseFloat(cart?.subtotal) + parseFloat(cart?.vat_value) + (fullAddress?.delivery_price ?? 0);
	}, [cart, fullAddress]);

	/*const _disabled = useMemo(() => {

		return sum === 0 || !fullAddress?.address || !fullAddress?.city_id || !fullAddress?.area_id || !recipientInfo?.first_name || !recipientInfo?.middle_name || !recipientInfo?.last_name || !recipientInfo?.phone || !recipientInfo?.email;
	}, [cart, fullAddress, recipientInfo]);*/

	const handleSubmit = async () => {
		if (!recipientInfo?.first_name || !recipientInfo?.middle_name || !recipientInfo?.last_name || !recipientInfo?.phone || !recipientInfo?.email) {
			setIsSubmitted(true);
			return;
		}

		startTransition(async () => {
			try {
				const _payload = {
					...recipientInfo,
					city_id: fullAddress?.city_id,
					area_id: fullAddress?.area_id,
					address: fullAddress?.address,
					location_lat: fullAddress?.location_lat,
					location_lng: fullAddress?.location_lng,
					additional_description: fullAddress?.additional_description,
					payment_callback_url: "https://bin-taleb-8jor.vercel.app/ar/cart?tab=2&status=pay"

				};
				console.log("payload: ", _payload);
				const result = await checkout(_payload);
				if (result?.success) {
					toast.success(t("The order was created successfully"), {
						style: { backgroundColor: "green", color: "white" },
					});

					router.push(result?.payment_url);
				} else {
					toast.error(t(result?.message?.replace(".", "")));
					if (result?.status === 401) router.push("/login");
				}
			} catch (error) {
				console.error("Error submitting form: ", error);
				toast.error("حدث خطأ أثناء التوصيل");
			}
		});
	};

	console.log("recipientInfo: ", recipientInfo);

	return (
		<div className="flex flex-col-reverse items-start justify-between gap-3 md:gap-9 lg:flex-row lg:gap-10 xl:gap-20">
			<div className="container mx-auto p-4 md:p-8 font-sans" dir="rtl">
				<h1 className="mb-2 text-xl leading-7 text-custom-primary-accent md:mb-4 md:text-[32px] md:leading-[76px]">الفاتورة</h1>

				{cart?.data?.length > 0 ?
					<div className="grid grid-cols-1 md:grid-cols-2 gap-6">
						{/* Left Panel */}
						<Card className="md:col-span-1 border-custom-primary-accent">
							<CardContent className="space-y-6 pt-6">
								{/* Recipient Information Section */}
								<div>
									<h3 className="text-lg font-semibold mb-3 text-right">
										معلومات المستلم
									</h3>

									<RadioGroup
										defaultValue="account"
										className="flex justify-end gap-24 mb-4"
										onValueChange={handleOptionChange}
									>
										<div
											className={`flex items-center rounded-lg border p-[9px] gap-2 ${selectedOption === "account" ? "border-custom-primary-accent" : ""}`}
											onClick={() => {
												// Use the handleOptionChange function to ensure proper state updates
												handleOptionChange("account");
											}}
										>
											<RadioGroupItem value="account" id="account" className="border-custom-primary-accent" />
											<Label htmlFor="account" className="cursor-pointer">استخدام معلومات حسابي</Label>
										</div>
										<div
											className={`flex items-center rounded-lg border p-[9px] gap-2 ${selectedOption === "new-info" ? "border-custom-primary-accent" : ""}`}
											onClick={() => {
												// Use the handleOptionChange function to ensure proper state updates
												handleOptionChange("new-info");
											}}
										>
											<RadioGroupItem value="new-info" id="new-info" className="border-custom-primary-accent" />
											<Label htmlFor="new-info" className="cursor-pointer">ادخال معلومات جديدة</Label>
										</div>
									</RadioGroup>

									{/* --- Dialog 1: Recipient Info --- */}
									<RecipientDialog
										onSave={handleRecipientSave}
										initialData={recipientInfo}
										key={`recipient-dialog-${selectedOption}-${JSON.stringify(recipientInfo)}`}
										disabledFields={selectedOption === "account" ? ["phone"] : []}
										isOpen={isRecipientDialogOpen}
										onOpenChange={handleDialogClose}
										title={selectedOption === "account" ? "معلومات حسابي" : "بيانات جديدة"}
									/>
									{/* --- End Dialog 1 --- */}

									{recipientInfo?.first_name &&
										<div className="flex flex-col mt-4 gap-2 justify-between rounded-lg border p-2 bg-[#2895c825]">
											{recipientInfo?.first_name && <p>الاسم: {recipientInfo?.first_name} {recipientInfo?.middle_name} {recipientInfo?.last_name}</p>}
											{recipientInfo?.phone && <p>الهاتف: {recipientInfo?.phone}</p>}
											{recipientInfo?.email && <p>البريد الإلكتروني: {recipientInfo?.email}</p>}
										</div>

									}

									{is_submitted && (!recipientInfo?.first_name || !recipientInfo?.middle_name || !recipientInfo?.last_name || !recipientInfo?.phone || !recipientInfo?.email) &&
										<div className="flex flex-col mt-4 gap-2 justify-between rounded-lg border p-2 bg-[#c8282816]">
											{!recipientInfo?.first_name && <span className="text-sm">الاسم الأول مطلوب</span>}
											{!recipientInfo?.middle_name && <span className="text-sm">الاسم الأوسط مطلوب</span>}
											{!recipientInfo?.last_name && <span className="text-sm">الاسم الأخير مطلوب</span>}
											{!recipientInfo?.phone && <span className="text-sm">الهاتف مطلوب</span>}
											{!recipientInfo?.email && <span className="text-sm">البريد الإلكتروني مطلوب</span>}
										</div>
									}

								</div>

								<Separator className="border-custom-primary-accent" />

								{/* Delivery Details Section */}
								<div>
									<h3 className="text-lg font-semibold mb-3 text-right">تفاصيل التوصيل</h3>
									{/* Delivery Address Input & Add Button */}
									<div className="space-y-3">
										{fullAddress?.address &&
											<div className="flex flex-col gap-2 justify-between rounded-lg border p-2 bg-[#2895c825]">
												{fullAddress?.address && <p>العنوان: {fullAddress?.address}</p>}
												{fullAddress?.city_name && <p>المدينة: {fullAddress?.city_name}</p>}
												{fullAddress?.area_name && <p>المنطقة: {fullAddress?.area_name}</p>}
											</div>
										}

										{is_submitted && !fullAddress?.address && !fullAddress?.city_name && !fullAddress?.area_name && <div className="flex flex-col mt-4 gap-2 justify-between rounded-lg border p-2 bg-[#c8282816]">
											{!fullAddress?.address && <span className="text-sm">العنوان مطلوب</span>}
											{!fullAddress?.city_name && <span className="text-sm">المدينة مطلوبة</span>}
											{!fullAddress?.area_name && <span className="text-sm">المنطقة مطلوبة</span>}
										</div>
										}

										{/* --- Dialog 2: Add Address --- */}
										<AddressDialog
											onSave={handleAddressSave}
											initialData={{
												city_id: fullAddress?.city_id,
												area_id: fullAddress?.area_id,
												address: fullAddress?.address,
												latitude: fullAddress?.location_lat,
												longitude: fullAddress?.location_lng
											}}
											key={`address-dialog-${selectedOption}`}
											disabledFields={selectedOption === "account" ? ["address"] : []}
										/>
										{/* --- End Dialog 2 --- */}

									</div>
								</div>
							</CardContent>
						</Card>

						{/* Right Panel (remains the same) */}
						<Card className="md:col-span-1">
							<CardHeader><CardTitle className="text-right">تفاصيل السعر</CardTitle></CardHeader>
							<CardContent className="space-y-4">
								{/* Price Breakdown */}
								<div className="space-y-2 text-right">
									<div className="flex justify-between">
										<span>سعر المنتج</span>
										<span className="flex items-center gap-2">
											{cart?.subtotal?.toFixed(2)}
											<Image
												src={"/coins/Saudi_Riyal.jpg"}
												alt="Saudi_Riyal"
												width={12}
												height={12}
											/>
										</span>
									</div>
									<div className="flex justify-between">
										<span>تكلفة التوصيل</span>
										<span className="flex items-center gap-2">
											{fullAddress?.delivery_price.toFixed(2)}
											<Image
												src={"/coins/Saudi_Riyal.jpg"}
												alt="Saudi_Riyal"
												width={12}
												height={12}
											/>
										</span>
									</div>
									<div className="flex justify-between">
										<span>ضرائب</span>
										<span className="flex items-center gap-2">
											{cart?.vat_value?.toFixed(2)}
											<Image
												src={"/coins/Saudi_Riyal.jpg"}
												alt="Saudi_Riyal"
												width={12}
												height={12}
											/>
										</span>
									</div>
								</div>
								<Separator />
								{/* Total Price */}
								<div className="flex justify-between font-bold text-lg text-right">
									<span>السعر الكلي</span>
									<span className="flex items-center gap-2">
										{sum}
										<Image
											src={"/coins/Saudi_Riyal.jpg"}
											alt="Saudi_Riyal"
											width={12}
											height={12}
										/>
									</span>
								</div>
							</CardContent>
							<CardFooter>
								<Button className="w-full" disabled={isPending}
									onClick={handleSubmit}
								>اكمال الشراء
									{isPending && <Loader2 className="w-4 h-4 ml-2 animate-spin" />}
								</Button>
							</CardFooter>
						</Card>
					</div>
					:
					<div className="flex flex-col items-center justify-center h-full">
						<h1 className="text-2xl font-bold">لا يوجد منتجات في السلة</h1>
					</div>

				}

			</div>
		</div>
	);
}
